@@ -48,4 +48,8 @@ helps = dict(
     logs = '''show log file
         arg = level (default to "info")
     ''',
+    outrun = '''show commands history
+    ''',
+    outlog = '''show commands log
+    ''',
 )
